#include "GUI.h"
#include "WM.h"
#include "DIALOG.h"
#include "math.h"
#include "stdio.h"
#include "N9H20.h"
#include "SmartPlug_Global.h"
/*********************************************************************
*
*       Defines
*
**********************************************************************
*/
WM_HWIN Create_PowerWindow(void);
extern void Create_DALIWindow(void);
extern volatile int Icon_Idex, Window_Idex;

extern GUI_CONST_STORAGE GUI_BITMAP bmICON_desktop320x240; 
extern GUI_CONST_STORAGE GUI_BITMAP bmICON_Power64x64; 
extern GUI_CONST_STORAGE GUI_BITMAP bmICON_Dali64x64;  
extern GUI_CONST_STORAGE GUI_BITMAP bmICON_Camera64x64;
extern GUI_CONST_STORAGE GUI_BITMAP bmICON_Sound64x64;  

typedef struct {
  const GUI_BITMAP * pBitmap;
  const char       * pText;
  const char       * pExplanation;
} BITMAP_ITEM;

const BITMAP_ITEM _aBitmapItem[] = {
    { &bmICON_Power64x64, "Power", " "},
	{ &bmICON_Dali64x64, "DALI", " "},
    { &bmICON_Camera64x64, "Cam", " "},
    { &bmICON_Sound64x64, "Music", " "},
};

/*********************************************************************
*
*       _cbDialog
*/
static void _cbDialog(WM_MESSAGE * pMsg) {
    WM_HWIN hItem;
    ICONVIEW_Handle hIcon;
    TEXT_Handle     hText;    
    int             i, Icon_Sel;
    int             NCode;
    int             Id;
  // USER START (Optionally insert additional variables)
  // USER END
    hItem = pMsg->hWin;
    switch (pMsg->MsgId) {
    
    case WM_CREATE:
//        WM_SetFocus(hItem);
        //
        // Create TEXT widget to display explanation text.
        //
        hText = TEXT_CreateEx(30, 180, 260, 40, hItem, WM_CF_SHOW, 0, GUI_ID_TEXT0, _aBitmapItem[0].pExplanation);
        TEXT_SetTextAlign(hText, GUI_TA_VCENTER | GUI_TA_HCENTER);
        TEXT_SetTextColor(hText, GUI_WHITE);
        TEXT_SetWrapMode(hText, GUI_WRAPMODE_WORD);
        TEXT_SetFont(hText, &GUI_Font20_1);
        //
        // Create ICONVIEW widget.
        //
        hIcon = ICONVIEW_CreateEx(20, 80, 280, 100, hItem, WM_CF_SHOW | WM_CF_HASTRANS, 0, GUI_ID_ICONVIEW0, 55, 90);
        for (i = 0; i < GUI_COUNTOF(_aBitmapItem); i++)
        {
            ICONVIEW_AddBitmapItem(hIcon, _aBitmapItem[i].pBitmap, _aBitmapItem[i].pText);
        }
//        ICONVIEW_SetBkColor(hIcon, ICONVIEW_CI_SEL, GUI_YELLOW);//ICONVIEW_CI_SEL,ICONVIEW_CI_BK
        ICONVIEW_SetBkColor(hIcon, ICONVIEW_CI_SEL, 0xFEFF0000);//ICONVIEW_CI_SEL,ICONVIEW_CI_BK
        ICONVIEW_SetSpace(hIcon, GUI_COORD_X, 17);
        ICONVIEW_SetSpace(hIcon, GUI_COORD_Y, 50);
        ICONVIEW_SetIconAlign(hIcon, ICONVIEW_IA_TOP);
//        ICONVIEW_SetFont(hIcon, &GUI_Font16_ASCII);
        ICONVIEW_SetFont(hIcon, &GUI_FontComic18B_1);
//        ICONVIEW_SetTextColor(hIcon, ICONVIEW_CI_SEL,   GUI_BLUE);
        ICONVIEW_SetTextColor(hIcon, ICONVIEW_CI_SEL,   GUI_YELLOW);
        ICONVIEW_SetTextColor(hIcon, ICONVIEW_CI_UNSEL, GUI_WHITE);
        ICONVIEW_SetSel(hIcon, Icon_Idex);        
//        WM_SetFocus(hIcon);
    break;

    case WM_PAINT:
        GUI_SetBkColor(GUI_BLUE);
        GUI_Clear();
        GUI_DrawBitmap(&bmICON_desktop320x240,0 ,0);
    break;
    
    case WM_NOTIFY_PARENT:
        Id    = WM_GetId(pMsg->hWinSrc);
        NCode = pMsg->Data.v;
		hIcon = WM_GetDialogItem(hItem, GUI_ID_ICONVIEW0);
		hText = WM_GetDialogItem(hItem, GUI_ID_TEXT0);    
        switch(Id) {
        case GUI_ID_ICONVIEW0: // Notifications sent by 'Iconview'
            Icon_Sel = ICONVIEW_GetSel(hIcon);
            switch(NCode) {
            case WM_NOTIFICATION_CLICKED:
                TEXT_SetText(hText, _aBitmapItem[Icon_Sel].pExplanation);
                //__nop();
            break;
            
            case WM_NOTIFICATION_RELEASED:
                switch (Icon_Sel)
                {
                    case 0:
//                        if(WiFi_Checking)
//                        {
                            WM_DeleteWindow(hItem);
                            Create_PowerWindow();                            
//                        }
                    break;   
                    case 1:
//                        if(WiFi_Checking)
//                        {
                            WM_DeleteWindow(hItem);
                            Create_DALIWindow();                             
//                        }           
                    break;   
                    case 2:
                    break;   
                    case 3:
                    break;                      
                }
            break;
            }
        break;
        }
    break;

    default:
    WM_DefaultProc(pMsg);
    break;
    }
}

/*********************************************************************
*
*       Public code
*
**********************************************************************
*/
/*********************************************************************
*
*       CreateWindow
*/
WM_HWIN Create_ICON_Window(void) {
  WM_HWIN hWin;
    Window_Idex = ICON_WINDOW;
  hWin = WM_CreateWindow(0, 0, WM_GetWindowSizeX(WM_HBKWIN), WM_GetWindowSizeY(WM_HBKWIN), WM_CF_SHOW, _cbDialog, 0);
  return hWin;
}

/*************************** End of file ****************************/
